==> masonite-2.1.0b1.tar.gz: masonite-2.1.0b1/masonite/snippets/auth/controllers/LoginController.py <==
""" A LoginController Module """

from masonite.auth import Auth
from masonite.request import Request
from masonite.view import View


class LoginController:
    """Login Form Controller
    """

    def __init__(self):
        """LoginContrller Constructor.
        """

        pass

    def show(self, request: Request, view: View):
        """Show the login page.

        Arguments:
            request {masonite.request.Request} -- The Masonite request class.
            view {masonite.view.View} -- The Masonite view class.

        Returns:
            masonite.view.View -- Returns the Masonite view class.
        """

        return view.render('auth/login', {'app': request.app.make('Application'), 'Auth': Auth(request)})

    def store(self, request: Request):
        """Login the user.

        Arguments:
            request {masonite.request.Request} -- The Masonite request class.

        Returns:
            masonite.request.Request -- The Masonite request class.
        """

        if Auth(request).login(request.input('username'), request.input('password')):
            return request.redirect('/home')

        return request.redirect('/login')

    def logout(self, request: Request):
        """Logs out the user.

        Arguments:
            request {masonite.request.Request} -- The Masonite request class.

        Returns:
            masonite.request.Request -- The Masonite request class.
        """

        Auth(request).logout()
        return request.redirect('/login')

==> masonite-2.1.2.tar.gz: masonite-2.1.2/masonite/snippets/auth/controllers/LoginController.py <==
"""A LoginController Module."""

from masonite.auth import Auth
from masonite.request import Request
from masonite.view import View


class LoginController:
    """Login Form Controller."""

    def __init__(self):
        """LoginController Constructor."""
        pass

    def show(self, request: Request, view: View):
        """Show the login page.

        Arguments:
            request {masonite.request.Request} -- The Masonite request class.
            view {masonite.view.View} -- The Masonite view class.

        Returns:
            masonite.view.View -- Returns the Masonite view class.
        """
        if request.user():
            return request.redirect('/home')
        return view.render('auth/login', {'app': request.app().make('Application'), 'Auth': Auth(request)})

    def store(self, request: Request):
        """Login the user.

        Arguments:
            request {masonite.request.Request} -- The Masonite request class.

        Returns:
            masonite.request.Request -- The Masonite request class.
        """
        if Auth(request).login(request.input('username'), request.input('password')):
            return request.redirect('/home')

        return request.redirect('/login')

    def logout(self, request: Request):
        """Log out the user.

        Arguments:
            request {masonite.request.Request} -- The Masonite request class.

        Returns:
            masonite.request.Request -- The Masonite request class.
        """
        Auth(request).logout()
        return request.redirect('/login')
